乐于分享
好东西不私藏

TensorRT-LLM 0.5.0 源码之三十四

TensorRT-LLM 0.5.0 源码之三十四

TopKSamplingLayer

template <typename T>class TopKSamplingLayer : public BaseSamplingLayer<T>{public:    using Base = BaseSamplingLayer<T>;    using SetupParams = typename Base::SetupParams;    TopKSamplingLayer(size_t vocab_size, size_t vocab_size_padded, cudaStream_t stream,        tensorrt_llm::common::IAllocator* allocator, bool is_free_buffer_after_forward);    TopKSamplingLayer(TopKSamplingLayer<T> const& top_k_sampling_layer);    ~TopKSamplingLayer();void setup(size_t batch_size, SetupParams const& setupParams);protected:void runSampling(DecodingOutputParams& outputs, DecodingParams const& params) override;void freeBuffer() override;    uint32_t runtime_max_top_k_ = 1;    uint32_t* runtime_top_k_buf_ = nullptr;    float* runtime_top_p_buf_ = nullptr;    using Base::vocab_size_;    using Base::vocab_size_padded_;    using Base::sampling_workspace_size_;    using Base::sampling_workspace_;    using Base::curandstate_buf_;    using Base::random_seeds_buf_;    using Base::skip_decode_buf_;    using Base::skip_decode_;    using Base::skip_any_;    using Base::runtime_logits_buf_;    using Base::stream_;    using Base::allocator_;    using Base::is_allocate_buffer_;private:void allocateBuffer(size_t batch_size, std::vector<uint32_t> const& top_k);};
template <typename T>TopKSamplingLayer<T>::TopKSamplingLayer(size_t vocab_size, size_t vocab_size_padded, cudaStream_t stream,    IAllocator* allocator, bool is_free_buffer_after_forward)    : BaseSamplingLayer<T>(vocab_size, vocab_size_padded, stream, allocator, is_free_buffer_after_forward, nullptr){}template <typename T>TopKSamplingLayer<T>::TopKSamplingLayer(TopKSamplingLayer<T> const& top_k_sampling_layer)    : BaseSamplingLayer<T>(top_k_sampling_layer){}template <typename T>TopKSamplingLayer<T>::~TopKSamplingLayer(){    TLLM_LOG_DEBUG(__PRETTY_FUNCTION__);    freeBuffer();}template class TopKSamplingLayer<float>;template class TopKSamplingLayer<half>;

allocateBuffer

top_k为0,底层会使用greedy_decode, 即top_k=1

template <typename T>void TopKSamplingLayer<T>::allocateBuffer(size_t const batch_size, std::vector<uint32_t> const& top_k){    TLLM_LOG_DEBUG(__PRETTY_FUNCTION__);    uint32_t max_top_k = (top_k.size() > 0) ? *std::max_element(std::begin(top_k), std::end(top_k)) : 1;    if (max_top_k == 0)    {        // for safety. TopKSamplingLayer handles a case of top_k=0 and top_p=0 as        // a greedy decode, i.e. top_k=1, although such case has max_top_k=0.        max_top_k = 1;    }    invokeTopKSampling<T>(nullptr, sampling_workspace_size_, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr,        nullptr, max_top_k, 1.0f, vocab_size_padded_, nullptr, stream_, batch_size, skip_decode_buf_);    sampling_workspace_ = allocator_->reMalloc(sampling_workspace_, sampling_workspace_size_, false);    runtime_top_k_buf_ = allocator_->reMalloc(runtime_top_k_buf_, sizeof(uint32_t) * batch_size, false); // [B,]    runtime_top_p_buf_ = allocator_->reMalloc(runtime_top_p_buf_, sizeof(float) * batch_size, false); // [B,]    is_allocate_buffer_ = true;}
template <typename T>void TopKSamplingLayer<T>::freeBuffer(){    TLLM_LOG_DEBUG(__PRETTY_FUNCTION__);    if (is_allocate_buffer_)    {        allocator_->free((void**) (&sampling_workspace_));        allocator_->free((void**) (&runtime_top_k_buf_));        allocator_->free((void**) (&runtime_top_p_buf_));    }    BaseSamplingLayer<T>::freeBuffer();    is_allocate_buffer_ = false;}

setup

  1. 1. topk=0 and top=0.0, 即greedy decode.
    • • 等价于 topk=1, topp=0.0
    • • 等价于 topk=1, topp=1.0
  2. 2. 最大 topk = 1024
  3. 3. 0.0 <= topp <= 1.0f
  4. 4. topk=0, skip_decode=True
template <typename T>void TopKSamplingLayer<T>::setup(size_t const batch_size, SetupParams const& setupParams){    TLLM_LOG_DEBUG(__PRETTY_FUNCTION__);    BaseSamplingLayer<T>::setupBase(batch_size, setupParams);    uint32_t const default_top_k = 0;    auto const runtime_top_k = setupParams.runtime_top_k.value_or(std::vector<uint32_t>{default_top_k});    auto const runtime_top_p = setupParams.runtime_top_p.value_or(std::vector<float>{});    allocateBuffer(batch_size, runtime_top_k);    size_t const runtime_top_k_size = runtime_top_k.size();    size_t const runtime_top_p_size = runtime_top_p.size();    uint32_t const top_k = *std::max_element(std::begin(runtime_top_k), std::end(runtime_top_k));    float const top_p = (runtime_top_p_size == 0) ? 0.0f : runtime_top_p.front();    if (runtime_top_k_size > 1)    {        TLLM_CHECK_WITH_INFO(runtime_top_k.size() == batch_size,            fmtstr(                "runtime_top_k.size() (%lu) == batch_size (%lu) is not satisfied!", runtime_top_k.size(), batch_size));        cudaAutoCpy(runtime_top_k_buf_, runtime_top_k.data(), batch_size, stream_);    }    if (runtime_top_p_size > 1)    {        TLLM_CHECK_WITH_INFO(runtime_top_p.size() == batch_size,            fmtstr(                "runtime_top_p.size() (%lu) == batch_size (%lu) is not satisfied!", runtime_top_p.size(), batch_size));        cudaAutoCpy(runtime_top_p_buf_, runtime_top_p.data(), batch_size, stream_);    }    dim3 block(std::min((int) batch_size, 256));    dim3 grid(divUp((int) batch_size, (int) block.x));    // support top_k up to 1024.    setup_topk_runtime_args<1024><<<grid, block, 0, stream_>>>(batch_size, top_k, runtime_top_k_buf_,        runtime_top_k_size, top_p, runtime_top_p_buf_, runtime_top_p_size, skip_decode_buf_);    cudaAutoCpy(skip_decode_, skip_decode_buf_, batch_size, stream_);    std::vector<uint32_t> runtime_top_ks(batch_size);    cudaAutoCpy(runtime_top_ks.data(), runtime_top_k_buf_, batch_size, stream_);    runtime_max_top_k_ = *std::max_element(std::begin(runtime_top_ks), std::end(runtime_top_ks));}

设置 runtime_top_k_buf_, runtime_top_p_buf_, skip_decode_buf_参数

template <uint32_t TOP_K_MAX>__global__ void setup_topk_runtime_args(int batch_size, uint32_t top_k, uint32_t* top_ks, int top_ks_size, float top_p,    float* top_ps, int top_ps_size, bool* skip_decode){    int index = blockIdx.x * blockDim.x + threadIdx.x;    for (int i = index; i < batch_size; i += gridDim.x * blockDim.x)    {        uint32_t k = top_ks_size > 1 ? top_ks[i] : top_k;        float p = top_ps_size > 1 ? top_ps[i] : top_p;        if (k == 0 && p == 0.0f)        {            // TensorRT-LLM's topp implementation does not support topp = 0.0f, but it            // equivalent to greedy search. So, we set the topk = 1 as an alternative            // solution.            k = 1;        }        if (k > 0 && p == 0.0f)        {            // for compatibility <= TensorRT-LLM5.0.            // This case corresponds to the old topk sampling, which is equivalent to            // the old topk_topp sampling with topp=1.0f. TopKSamplingLayer and            // TopKTopPSamplingLayer are now merged by TopKSamplingLayer. Thus, we            // replace the case topk>0 and topp=0.0f by topk>0 and topp=1.0f for the            // compatibility.            p = 1.0f;        }        // Clip k value. A topk sampling kernel supports up to TOP_K_MAX=64.        top_ks[i] = k > TOP_K_MAX ? TOP_K_MAX : k;        if (k > TOP_K_MAX)        {            printf(                "[WARNING] topk (%d) is larger than max supported number (%d) for "                "token %d"                " clip to max supported number %d. \n",                k, TOP_K_MAX, i, top_ks[i]);        }        // Clip p value if it is out of range. range = [0.0, 1.0].        top_ps[i] = p < 0.0f ? 0.0f : (p > 1.0f ? 1.0f : p);        if (p < 0.0f || p > 1.0f)        {            printf(                "[WARNING] topp (%f) is out of range ([0.0, 1.0f]) for token %d"                " clip to closest number %f.\n",                p, i, top_ps[i]);        }        skip_decode[i] = k == 0;    }}

runSampling

template <typename T>void TopKSamplingLayer<T>::runSampling(DecodingOutputParams& outputs, DecodingParams const& params){    TLLM_LOG_DEBUG("%s start", __PRETTY_FUNCTION__);    auto const batch_size = outputs.output_ids_ptr.shape[0];    auto const local_batch_size = params.logits.shape[0];    auto const ite = params.ite;    // in case of skip any, the logit value is already copied and processed.    auto* logits = !skip_any_ ? params.logits.template getPtr<T>() : runtime_logits_buf_;    auto* end_ids = params.end_ids.template getPtr<const int>();    bool* finished = (outputs.finished) ? outputs.finished->template getPtr<bool>() : nullptr;    invokeAddBiasEndMask(        logits, (T*) (nullptr), end_ids, finished, local_batch_size, vocab_size_, vocab_size_padded_, stream_);    sync_check_cuda_error();    float* cum_log_probs = (outputs.cum_log_probs) ? outputs.cum_log_probs->template getPtr<float>() : nullptr;    float* output_log_probs = (outputs.output_log_probs) ? outputs.output_log_probs->template getPtr<float>() : nullptr;    if (cum_log_probs != nullptr || output_log_probs != nullptr)    {        invokeAddBiasSoftMax(            logits, (T*) (nullptr), end_ids, finished, local_batch_size, vocab_size_padded_, vocab_size_, stream_);        sync_check_cuda_error();    }    int* sequence_length = (outputs.sequence_length) ? outputs.sequence_length->template getPtr<int>() : nullptr;    invokeBatchTopKSampling(sampling_workspace_, sampling_workspace_size_, logits,        outputs.output_ids_ptr.template getPtr<int*>(), sequence_length, finished, cum_log_probs, output_log_probs,        curandstate_buf_ + ite * local_batch_size,        (int) runtime_max_top_k_, // useless because runtime_top_k_buf_ is never                                  // nullptr. Keep for legacy.        (int*) (runtime_top_k_buf_ + ite * local_batch_size),        1.0f,                     // useless because runtime_top_p_buf_ is never nullptr. Keep for                                  // legacy.        runtime_top_p_buf_ + ite * local_batch_size, vocab_size_padded_, end_ids, stream_, local_batch_size,        skip_decode_buf_ + ite * local_batch_size);    sync_check_cuda_error();}

TopPSamplingLayer

template <typename T>class TopPSamplingLayer : public BaseSamplingLayer<T>{public:    using Base = BaseSamplingLayer<T>;    class SetupParams : public Base::SetupParams    {    public:        std::optional<std::vector<float>> top_p_decay;            // [batch_size], must between [0, 1]        std::optional<std::vector<float>> top_p_min;              // [batch_size], must between [0, 1]        std::optional<std::vector<std::int32_t>> top_p_reset_ids; // [batch_size]    };    TopPSamplingLayer(std::size_t vocab_size, std::size_t vocab_size_padded, cudaStream_t stream,        tensorrt_llm::common::IAllocator* allocator, bool is_free_buffer_after_forward,        cudaDeviceProp* cuda_device_prop);    TopPSamplingLayer(TopPSamplingLayer<T> const& top_p_sampling_layer);    ~TopPSamplingLayer();void setup(std::size_t batch_size, SetupParams const& setupParams);protected:void runSampling(DecodingOutputParams& outputs, DecodingParams const& params) override;void freeBuffer() override;    std::uint32_t* runtime_top_k_buf_ = nullptr;    float* runtime_top_p_buf_ = nullptr;    float runtime_max_top_p_;    float* initial_top_p_buf_ = nullptr;    float* top_p_decay_buf_ = nullptr;    float* top_p_min_buf_ = nullptr;    std::int32_t* top_p_reset_ids_buf_ = nullptr;    std::int32_t* topp_id_vals_buf_ = nullptr;    std::int32_t* topp_offset_buf_ = nullptr;    std::int32_t* begin_topp_offset_buf_ = nullptr;    std::size_t cub_temp_storage_size_;    using Base::vocab_size_;    using Base::vocab_size_padded_;    using Base::sampling_workspace_size_;    using Base::sampling_workspace_;    using Base::curandstate_buf_;    using Base::random_seeds_buf_;    using Base::skip_decode_buf_;    using Base::skip_decode_;    using Base::skip_any_;    using Base::runtime_logits_buf_;    using Base::stream_;    using Base::allocator_;    using Base::is_allocate_buffer_;    using Base::cuda_device_prop_;private:void allocateBuffer(std::size_t batch_size, std::vector<float> const& top_k);};
template <typename T>TopPSamplingLayer<T>::TopPSamplingLayer(std::size_t vocab_size, std::size_t vocab_size_padded, cudaStream_t stream,    IAllocator* allocator, bool is_free_buffer_after_forward, cudaDeviceProp* cuda_device_prop)    : BaseSamplingLayer<T>(        vocab_size, vocab_size_padded, stream, allocator, is_free_buffer_after_forward, cuda_device_prop){}template <typename T>TopPSamplingLayer<T>::TopPSamplingLayer(TopPSamplingLayer<T> const& top_p_sampling_layer)    : BaseSamplingLayer<T>(top_p_sampling_layer){}template <typename T>TopPSamplingLayer<T>::~TopPSamplingLayer(){    TLLM_LOG_DEBUG(__PRETTY_FUNCTION__);    freeBuffer();}template class TopPSamplingLayer<float>;template class TopPSamplingLayer<half>;

allocateBuffer

template <typename T>void TopPSamplingLayer<T>::allocateBuffer(std::size_t batch_size, std::vector<float> const& top_p){    TLLM_LOG_DEBUG(__PRETTY_FUNCTION__);    float const max_top_p = (top_p.size() > 0) ? *std::max_element(std::begin(top_p), std::end(top_p)) : 0.0f;    invokeTopPSampling<T>(nullptr, // workspace        sampling_workspace_size_, cub_temp_storage_size_,        nullptr,                   // output_ids        nullptr,                   // sequence_length        nullptr,                   // finished_buffer        nullptr,                   // cum_log_probs        nullptr,                   // output_log_probs        nullptr,                   // log_probs        topp_id_vals_buf_, topp_offset_buf_, begin_topp_offset_buf_, curandstate_buf_, batch_size, vocab_size_padded_,        nullptr, max_top_p, stream_, cuda_device_prop_, skip_decode_buf_);    sampling_workspace_ = allocator_->reMalloc(sampling_workspace_, sampling_workspace_size_, true);    runtime_top_k_buf_ = allocator_->reMalloc(runtime_top_k_buf_, sizeof(std::uint32_t) * batch_size, false);    runtime_top_p_buf_ = allocator_->reMalloc(runtime_top_p_buf_, sizeof(float) * batch_size, false);    initial_top_p_buf_ = allocator_->reMalloc(initial_top_p_buf_, sizeof(float) * batch_size, false);    top_p_decay_buf_ = allocator_->reMalloc(top_p_decay_buf_, sizeof(float) * batch_size, false);    top_p_min_buf_ = allocator_->reMalloc(top_p_min_buf_, sizeof(float) * batch_size, false);    top_p_reset_ids_buf_ = allocator_->reMalloc(top_p_reset_ids_buf_, sizeof(std::int32_t) * batch_size, false);    topp_id_vals_buf_        = allocator_->reMalloc(topp_id_vals_buf_, sizeof(std::int32_t) * batch_size * vocab_size_padded_, false);    topp_offset_buf_ = allocator_->reMalloc(topp_offset_buf_, sizeof(std::int32_t) * (batch_size + 1), false);    begin_topp_offset_buf_        = allocator_->reMalloc(begin_topp_offset_buf_, sizeof(std::int32_t) * (batch_size + 1), false);    is_allocate_buffer_ = true;}
template <typename T>void TopPSamplingLayer<T>::freeBuffer(){    TLLM_LOG_DEBUG(__PRETTY_FUNCTION__);    if (is_allocate_buffer_)    {        allocator_->free((void**) (&sampling_workspace_));        allocator_->free((void**) (&topp_id_vals_buf_));        allocator_->free((void**) (&topp_offset_buf_));        allocator_->free((void**) (&begin_topp_offset_buf_));        allocator_->free((void**) (&runtime_top_k_buf_));        allocator_->free((void**) (&runtime_top_p_buf_));        allocator_->free((void**) (&initial_top_p_buf_));        allocator_->free((void**) (&top_p_decay_buf_));        allocator_->free((void**) (&top_p_min_buf_));        allocator_->free((void**) (&top_p_reset_ids_buf_));    }    BaseSamplingLayer<T>::freeBuffer();    is_allocate_buffer_ = false;}

setup

  1. 1. topk=0 and topp=0.0, greedy decode topk=1
  2. 2. topk > 0 , skip_decode = True
  3. 3. default top_p_decay = 1.0
  4. 4. default top_p_min = 0.5f
template <typename T>void TopPSamplingLayer<T>::setup(std::size_t const batch_size, SetupParams const& setupParams){    TLLM_LOG_DEBUG(__PRETTY_FUNCTION__);    BaseSamplingLayer<T>::setupBase(batch_size, setupParams);    std::uint32_t const default_top_k = 0;    auto const runtime_top_k = setupParams.runtime_top_k.value_or(std::vector<uint32_t>{default_top_k});    auto const runtime_top_p = setupParams.runtime_top_p.value_or(std::vector<float>{});    allocateBuffer(batch_size, runtime_top_p);    std::size_t const runtime_top_k_size = runtime_top_k.size();    std::size_t const runtime_top_p_size = runtime_top_p.size();    if (runtime_top_p_size == 0)    {        std::fill_n(skip_decode_, batch_size, true);        return;    }    std::uint32_t const top_k = runtime_top_k.at(0);    float const top_p = runtime_top_p.at(0);    if (runtime_top_k_size > 1)    {        TLLM_CHECK_WITH_INFO(runtime_top_k.size() == batch_size,            fmtstr(                "runtime_top_k.size() (%lu) == batch_size (%lu) is not satisfied!", runtime_top_k.size(), batch_size));        cudaAutoCpy(runtime_top_k_buf_, runtime_top_k.data(), batch_size, stream_);    }    if (runtime_top_p_size > 1)    {        TLLM_CHECK_WITH_INFO(runtime_top_p.size() == batch_size,            fmtstr(                "runtime_top_p.size() (%lu) == batch_size (%lu) is not satisfied!", runtime_top_p.size(), batch_size));        cudaAutoCpy(runtime_top_p_buf_, runtime_top_p.data(), batch_size, stream_);    }    auto fillBuffers = [this, &batch_size](std::string name, auto const& vector, auto& deviceBuffer)    {        TLLM_CHECK_WITH_INFO(vector.size() == batch_size,            fmtstr("%s.size() (%lu) == batch_size (%lu) is not satisfied!", name.c_str(), vector.size(), batch_size));        cudaAutoCpy(deviceBuffer, vector.data(), batch_size, stream_);    };    float const defaultTopPDecay{1.0f};    fillBuffers("top_p_decay", setupParams.top_p_decay.value_or(std::vector<float>(batch_size, defaultTopPDecay)),        top_p_decay_buf_);    float const defaultTopPMin{1e-6f}; // prevent topp becoming 0.0    fillBuffers(        "top_p_min", setupParams.top_p_min.value_or(std::vector<float>(batch_size, defaultTopPMin)), top_p_min_buf_);    std::int32_t const defaultTopPResetId{-1};    fillBuffers("top_p_reset_ids",        setupParams.top_p_reset_ids.value_or(std::vector<std::int32_t>(batch_size, defaultTopPResetId)),        top_p_reset_ids_buf_);    dim3 block(std::min((int) batch_size, 256));    dim3 grid(divUp((int) batch_size, (int) block.x));    set_topp_runtime_args<<<grid, block, 0, stream_>>>(batch_size, top_k, runtime_top_k_buf_, runtime_top_k_size, top_p,        runtime_top_p_buf_, runtime_top_p_size, skip_decode_buf_, initial_top_p_buf_, top_p_decay_buf_, top_p_min_buf_);    sync_check_cuda_error();    cudaAutoCpy(skip_decode_, skip_decode_buf_, batch_size, stream_);    std::vector<float> runtime_top_ps(batch_size);    cudaAutoCpy(runtime_top_ps.data(), runtime_top_p_buf_, batch_size, stream_);    runtime_max_top_p_ = *std::max_element(std::begin(runtime_top_ps), std::end(runtime_top_ps));}
static __global__ void set_topp_runtime_args(int batch_size, std::uint32_t top_k, std::uint32_t* top_ks,    int top_ks_size, float top_p, float* top_ps, int top_ps_size, bool* skip_decode, float* initial_top_p_buf,    float* top_p_decay_buf, float* top_p_min_buf){    /**     * @brief Setup the runtime arguments for topp, broadcasting top_p to top_ps              and top_k to top_ks, verifying value ranges of top_p_decay/top_p_min.     *     * \param batch_size     * \param top_k                 first top_k     * \param top_ks                [batch_size]     * \param top_ks_size     * \param top_p                 first top_p     * \param top_ps                [batch_size]     * \param top_ps_size     * \param skip_decode           [batch_size]     * \param initial_top_p_buf     [batch_size]     * \param top_p_decay_buf       [batch_size]     * \param top_p_min_buf         [batch_size]     *     */    int index = blockIdx.x * blockDim.x + threadIdx.x;    for (int i = index; i < batch_size; i += gridDim.x * blockDim.x)    {        std::uint32_t k = top_ks_size > 1 ? top_ks[i] : top_k;        float p = top_ps_size > 1 ? top_ps[i] : top_p;        if (k == 0 && p == 0.0f)        {            // TensorRT-LLM's topp implementation does not support topp = 0.0f, but it            // equivalent to greedy search. So, we set the topk = 1 as an alternative            // solution.            k = 1;        }        top_ks[i] = k;        // Clip p value if it is out of range. range = [0.0, 1.0].        top_ps[i] = p < 0.0f ? 0.0f : (p > 1.0f ? 1.0f : p);        if (p < 0.0f || p > 1.0f)        {            printf(                "[WARNING] topp (%f) is out of range ([0.0, 1.0f]) for token %d"                " clip to closest number %f.\n",                p, i, top_ps[i]);        }        skip_decode[i] = k > 0;  // Warning        initial_top_p_buf[i] = top_ps[i];        if (top_p_decay_buf[i] > 1.0f || top_p_decay_buf[i] <= 0.0f)        {            printf(                "[WARNING] top_p_decay_buf (%f) is out of range ([0.0, 1.0f]) for "                "token %d,"                " change to 1.0f.\n",                top_p_decay_buf[i], i);            top_p_decay_buf[i] = 1.0f;        }        if (top_p_min_buf[i] > 1.0f || top_p_min_buf[i] <= 0.0f)        {            printf(                "[WARNING] top_p_min_buf (%f) is out of range ([0.0, 1.0f]) for "                "token %d,"                " change to 0.5f.\n",                top_p_min_buf[i], i);            top_p_min_buf[i] = 0.5f;        }    }}

runSampling

template <typename T>void TopPSamplingLayer<T>::runSampling(DecodingOutputParams& outputs, DecodingParams const& params){    TLLM_LOG_DEBUG(__PRETTY_FUNCTION__);    auto const batch_size = outputs.output_ids_ptr.shape[0];    auto const local_batch_size = params.logits.shape[0];    auto const ite = params.ite;    // in case of skip any, the logit value is already copied and processed.    auto* logits = !skip_any_ ? params.logits.template getPtr<T>() : runtime_logits_buf_;    auto* end_ids = params.end_ids.template getPtr<const int>();    invokeTopPInitialize(        topp_id_vals_buf_, topp_offset_buf_, begin_topp_offset_buf_, local_batch_size, vocab_size_padded_, stream_);    sync_check_cuda_error();    bool* finished = (outputs.finished) ? outputs.finished->template getPtr<bool>() : nullptr;    invokeAddBiasSoftMax(        logits, (T*) (nullptr), end_ids, finished, local_batch_size, vocab_size_padded_, vocab_size_, stream_);    sync_check_cuda_error();    float* cum_log_probs = (outputs.cum_log_probs) ? outputs.cum_log_probs->template getPtr<float>() : nullptr;    float* output_log_probs = (outputs.output_log_probs) ? outputs.output_log_probs->template getPtr<float>() : nullptr;    int* sequence_length = (outputs.sequence_length) ? outputs.sequence_length->template getPtr<int>() : nullptr;    invokeBatchTopPSampling<T>(sampling_workspace_, sampling_workspace_size_, cub_temp_storage_size_,        outputs.output_ids_ptr.template getPtr<int*>(), sequence_length, finished, cum_log_probs, output_log_probs,        logits, topp_id_vals_buf_, topp_offset_buf_, begin_topp_offset_buf_, curandstate_buf_ + ite * local_batch_size,        local_batch_size, vocab_size_padded_, end_ids, runtime_max_top_p_, runtime_top_p_buf_ + ite * local_batch_size,        stream_, cuda_device_prop_, skip_decode_buf_ + ite * local_batch_size);    sync_check_cuda_error();    invokeComputeToppDecay(runtime_top_p_buf_ + ite * local_batch_size, initial_top_p_buf_ + ite * local_batch_size,        outputs.output_ids_ptr.template getPtr<const int*>(), top_p_decay_buf_ + ite * local_batch_size,        top_p_min_buf_ + ite * local_batch_size, top_p_reset_ids_buf_ + ite * local_batch_size, sequence_length,        local_batch_size, stream_);    sync_check_cuda_error();}

参考文献

  • • https://github.com/NVIDIA/TensorRT-LLM/blob/v0.5.0/cpp/tensorrt_llm/kernels/samplingPenaltyKernels.h
  • • https://github.com/NVIDIA/TensorRT-LLM/blob/release/0.5.0/cpp/tensorrt_llm/layers/topPSamplingLayer.h
点个「赞」+「在看」❤️
让我们知道这份文字有温暖到你,也是我们持续创作的最大动力!
推荐
TensorRT-LLM 0.5.0 源码之三十五
技能:规定智能体应该如何思考
借助AI进行写作与思考
大型数据集与结构化数据库:经济学家使用Claude Code
从 EDGAR 文件到结构化数据库:使用 Claude Code
循环工程:设计编码代理系统,而不是每次都手动提示
VoxCPM2 技术报告
信息差的消失
Agent 数据生产与训练
基准测试设计:选择开放模型测试与封闭模型测试
gRPC 使用建议
flashinfer.sampling 实现四
AI 时代的组织变更
TensorRT-LLM 0.5.0 源码之二十七
flashinfer.sampling 实现三
什么是循环工程?AI 编码智能体的新范式
Trae IDE 实战指南:核心AI功能、Skill运用与项目开发全流程
Small matrix multiplication - Triton
从空文件夹到生成图表:Claude Code 实战教程
Claude Code 入门:研究者配置指南
Claude Code 究竟擅长什么?一次实测验证
GLM-5.2:面向长时序任务打造
Anthropic Fable 5
循环工程(Loop Engineering)
Agent SFT 标准数据格式 + Loss Mask 完整实现
4D Parallelism
TileLang与OpenAI Triton的核心区别
TensorRT-LLM 0.5.0 源码之二十六
Agent SFT 数据
Claude Code 的上限,就是你的上限
如何用Claude Code提升软件工程工作效率、改善生活
LLM推理优化的核心技术:深入理解KV缓存与分页注意力机制
MiMo-V2-Flash技术报告
AI原生开发中的MCP与CLI对比
Qwen3-TTS 技术报告
PagedAttention
如何让AI听懂你的“话外音”?GOAT-SLM模型实现更懂情感的语言交互
FlashAttention与PagedAttention详解:拯救GPU显存,让大模型飞起来的核心技术
LM-as-a-judge:LLM评估指南
LLM Sequence Packing
深入了解SmoothQuant:大模型高效量化背后的数学原理
语音合成(TTS)分句生成拼接时的响度一致性问题:现状、成因与对策
当扩散模型遇上流匹配:原来是一回事儿
语音合成中的“一对多”问题主流模型解决方案分析
使用LoRA对LLM进行微调的实用技巧
语音合成(TTS)中文自然度:问题、成因、解决方案
语音合成(TTS)跳跃与重复问题的解析:成因、机制及解决方案
最新!SpeechLLM 综述:架构、能力、挑战与未来全揭秘
基本 文件 流程 错误 SQL 调试
  1. 请求信息 : 2026-08-11 22:07:01 HTTP/1.1 GET : https://www.yeyulingfeng.com/a/924855.html
  2. 运行时间 : 0.140198s [ 吞吐率:7.13req/s ] 内存消耗:4,807.74kb 文件加载:145
  3. 缓存信息 : 0 reads,0 writes
  4. 会话信息 : SESSION_ID=d49438e9f20d8cd9d8823d7eb4357a64
  1. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/public/index.php ( 0.79 KB )
  2. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/autoload.php ( 0.17 KB )
  3. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/composer/autoload_real.php ( 2.49 KB )
  4. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/composer/platform_check.php ( 0.90 KB )
  5. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/composer/ClassLoader.php ( 14.03 KB )
  6. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/composer/autoload_static.php ( 6.05 KB )
  7. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-helper/src/helper.php ( 8.34 KB )
  8. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-validate/src/helper.php ( 2.19 KB )
  9. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/ralouphie/getallheaders/src/getallheaders.php ( 1.60 KB )
  10. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/helper.php ( 1.47 KB )
  11. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/stubs/load_stubs.php ( 0.16 KB )
  12. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Exception.php ( 1.69 KB )
  13. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-container/src/Facade.php ( 2.71 KB )
  14. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/symfony/deprecation-contracts/function.php ( 0.99 KB )
  15. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/symfony/polyfill-mbstring/bootstrap.php ( 8.26 KB )
  16. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/symfony/polyfill-mbstring/bootstrap80.php ( 9.78 KB )
  17. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/symfony/var-dumper/Resources/functions/dump.php ( 1.49 KB )
  18. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-dumper/src/helper.php ( 0.18 KB )
  19. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/symfony/var-dumper/VarDumper.php ( 4.30 KB )
  20. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/guzzlehttp/guzzle/src/functions_include.php ( 0.16 KB )
  21. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/guzzlehttp/guzzle/src/functions.php ( 5.54 KB )
  22. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/App.php ( 15.30 KB )
  23. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-container/src/Container.php ( 15.76 KB )
  24. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/psr/container/src/ContainerInterface.php ( 1.02 KB )
  25. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/app/provider.php ( 0.19 KB )
  26. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Http.php ( 6.04 KB )
  27. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-helper/src/helper/Str.php ( 7.29 KB )
  28. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Env.php ( 4.68 KB )
  29. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/app/common.php ( 0.03 KB )
  30. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/helper.php ( 18.78 KB )
  31. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Config.php ( 5.54 KB )
  32. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/alipay.php ( 3.59 KB )
  33. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/facade/Env.php ( 1.67 KB )
  34. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/app.php ( 0.95 KB )
  35. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/cache.php ( 0.78 KB )
  36. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/console.php ( 0.23 KB )
  37. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/cookie.php ( 0.56 KB )
  38. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/database.php ( 2.48 KB )
  39. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/filesystem.php ( 0.61 KB )
  40. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/lang.php ( 0.91 KB )
  41. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/log.php ( 1.35 KB )
  42. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/middleware.php ( 0.19 KB )
  43. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/route.php ( 1.89 KB )
  44. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/session.php ( 0.57 KB )
  45. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/trace.php ( 0.34 KB )
  46. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/config/view.php ( 0.82 KB )
  47. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/app/event.php ( 0.25 KB )
  48. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Event.php ( 7.67 KB )
  49. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/app/service.php ( 0.13 KB )
  50. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/app/AppService.php ( 0.26 KB )
  51. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Service.php ( 1.64 KB )
  52. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Lang.php ( 7.35 KB )
  53. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/lang/zh-cn.php ( 13.70 KB )
  54. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/initializer/Error.php ( 3.31 KB )
  55. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/initializer/RegisterService.php ( 1.33 KB )
  56. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/services.php ( 0.14 KB )
  57. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/service/PaginatorService.php ( 1.52 KB )
  58. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/service/ValidateService.php ( 0.99 KB )
  59. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/service/ModelService.php ( 2.04 KB )
  60. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-trace/src/Service.php ( 0.77 KB )
  61. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Middleware.php ( 6.72 KB )
  62. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/initializer/BootService.php ( 0.77 KB )
  63. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/Paginator.php ( 11.86 KB )
  64. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-validate/src/Validate.php ( 63.20 KB )
  65. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/Model.php ( 23.55 KB )
  66. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/model/concern/Attribute.php ( 21.05 KB )
  67. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/model/concern/AutoWriteData.php ( 4.21 KB )
  68. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/model/concern/Conversion.php ( 6.44 KB )
  69. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/model/concern/DbConnect.php ( 5.16 KB )
  70. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/model/concern/ModelEvent.php ( 2.33 KB )
  71. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/model/concern/RelationShip.php ( 28.29 KB )
  72. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-helper/src/contract/Arrayable.php ( 0.09 KB )
  73. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-helper/src/contract/Jsonable.php ( 0.13 KB )
  74. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/model/contract/Modelable.php ( 0.09 KB )
  75. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Db.php ( 2.88 KB )
  76. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/DbManager.php ( 8.52 KB )
  77. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Log.php ( 6.28 KB )
  78. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Manager.php ( 3.92 KB )
  79. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/psr/log/src/LoggerTrait.php ( 2.69 KB )
  80. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/psr/log/src/LoggerInterface.php ( 2.71 KB )
  81. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Cache.php ( 4.92 KB )
  82. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/psr/simple-cache/src/CacheInterface.php ( 4.71 KB )
  83. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-helper/src/helper/Arr.php ( 16.63 KB )
  84. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/cache/driver/File.php ( 7.84 KB )
  85. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/cache/Driver.php ( 9.03 KB )
  86. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/contract/CacheHandlerInterface.php ( 1.99 KB )
  87. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/app/Request.php ( 0.09 KB )
  88. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Request.php ( 55.78 KB )
  89. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/app/middleware.php ( 0.25 KB )
  90. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Pipeline.php ( 2.61 KB )
  91. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-trace/src/TraceDebug.php ( 3.40 KB )
  92. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/middleware/SessionInit.php ( 1.94 KB )
  93. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Session.php ( 1.80 KB )
  94. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/session/driver/File.php ( 6.27 KB )
  95. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/contract/SessionHandlerInterface.php ( 0.87 KB )
  96. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/session/Store.php ( 7.12 KB )
  97. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Route.php ( 23.73 KB )
  98. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/route/RuleName.php ( 5.75 KB )
  99. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/route/Domain.php ( 2.53 KB )
  100. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/route/RuleGroup.php ( 22.43 KB )
  101. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/route/Rule.php ( 26.95 KB )
  102. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/route/RuleItem.php ( 9.78 KB )
  103. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/route/app.php ( 4.22 KB )
  104. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/facade/Route.php ( 4.70 KB )
  105. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/route/dispatch/Controller.php ( 4.74 KB )
  106. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/route/Dispatch.php ( 10.44 KB )
  107. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/app/controller/Index.php ( 9.87 KB )
  108. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/app/BaseController.php ( 2.05 KB )
  109. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/facade/Db.php ( 0.93 KB )
  110. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/connector/Mysql.php ( 5.44 KB )
  111. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/PDOConnection.php ( 52.47 KB )
  112. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/Connection.php ( 8.39 KB )
  113. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/ConnectionInterface.php ( 4.57 KB )
  114. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/builder/Mysql.php ( 16.58 KB )
  115. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/Builder.php ( 24.06 KB )
  116. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/BaseBuilder.php ( 27.50 KB )
  117. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/Query.php ( 15.71 KB )
  118. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/BaseQuery.php ( 45.13 KB )
  119. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/concern/TimeFieldQuery.php ( 7.43 KB )
  120. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/concern/AggregateQuery.php ( 3.26 KB )
  121. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/concern/ModelRelationQuery.php ( 20.07 KB )
  122. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/concern/ParamsBind.php ( 3.66 KB )
  123. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/concern/ResultOperation.php ( 7.01 KB )
  124. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/concern/WhereQuery.php ( 19.37 KB )
  125. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/concern/JoinAndViewQuery.php ( 7.11 KB )
  126. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/concern/TableFieldInfo.php ( 2.63 KB )
  127. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-orm/src/db/concern/Transaction.php ( 2.77 KB )
  128. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/log/driver/File.php ( 5.96 KB )
  129. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/contract/LogHandlerInterface.php ( 0.86 KB )
  130. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/log/Channel.php ( 3.89 KB )
  131. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/event/LogRecord.php ( 1.02 KB )
  132. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-helper/src/Collection.php ( 16.47 KB )
  133. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/facade/View.php ( 1.70 KB )
  134. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/View.php ( 4.39 KB )
  135. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/app/controller/Es.php ( 3.11 KB )
  136. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Response.php ( 8.81 KB )
  137. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/response/View.php ( 3.29 KB )
  138. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/Cookie.php ( 6.06 KB )
  139. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-view/src/Think.php ( 8.38 KB )
  140. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/framework/src/think/contract/TemplateHandlerInterface.php ( 1.60 KB )
  141. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-template/src/Template.php ( 46.61 KB )
  142. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-template/src/template/driver/File.php ( 2.41 KB )
  143. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-template/src/template/contract/DriverInterface.php ( 0.86 KB )
  144. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/runtime/temp/c935550e3e8a3a4c27dd94e439343fdf.php ( 31.50 KB )
  145. /yingpanguazai/ssd/ssd1/www/wwww.yeyulingfeng.com/vendor/topthink/think-trace/src/Html.php ( 4.42 KB )
  1. CONNECT:[ UseTime:0.001067s ] mysql:host=127.0.0.1;port=3306;dbname=wenku;charset=utf8mb4
  2. SHOW FULL COLUMNS FROM `fenlei` [ RunTime:0.001924s ]
  3. SELECT * FROM `fenlei` WHERE `fid` = 0 [ RunTime:0.000807s ]
  4. SELECT * FROM `fenlei` WHERE `fid` = 63 [ RunTime:0.000759s ]
  5. SHOW FULL COLUMNS FROM `set` [ RunTime:0.001764s ]
  6. SELECT * FROM `set` [ RunTime:0.000659s ]
  7. SHOW FULL COLUMNS FROM `article` [ RunTime:0.001998s ]
  8. SELECT * FROM `article` WHERE `id` = 924855 LIMIT 1 [ RunTime:0.001428s ]
  9. UPDATE `article` SET `lasttime` = 1786457221 WHERE `id` = 924855 [ RunTime:0.016913s ]
  10. SELECT * FROM `fenlei` WHERE `id` = 64 LIMIT 1 [ RunTime:0.004825s ]
  11. SELECT * FROM `article` WHERE `id` < 924855 ORDER BY `id` DESC LIMIT 1 [ RunTime:0.001632s ]
  12. SELECT * FROM `article` WHERE `id` > 924855 ORDER BY `id` ASC LIMIT 1 [ RunTime:0.001237s ]
  13. SELECT * FROM `article` WHERE `id` < 924855 ORDER BY `id` DESC LIMIT 10 [ RunTime:0.008111s ]
  14. SELECT * FROM `article` WHERE `id` < 924855 ORDER BY `id` DESC LIMIT 10,10 [ RunTime:0.004146s ]
  15. SELECT * FROM `article` WHERE `id` < 924855 ORDER BY `id` DESC LIMIT 20,10 [ RunTime:0.003775s ]
0.141963s